@@ -57,6 +57,7 @@ __all__ = (
     "TrustStateType",
     "TrustTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -421,10 +422,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -432,3 +435,14 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_directories",
+    "describe_domain_controllers",
+    "describe_shared_directories",
+    "describe_snapshots",
+    "describe_trusts",
+    "list_ip_routes",
+    "list_log_subscriptions",
+    "list_schema_extensions",
+    "list_tags_for_resource",
+]
